pub struct Pkcs12Builder { /* private fields */ }Implementations
Sourceimpl Pkcs12Builder
impl Pkcs12Builder
Sourcepub fn key_algorithm(&mut self, nid: Nid) -> &mut Self
pub fn key_algorithm(&mut self, nid: Nid) -> &mut Self
The encryption algorithm that should be used for the key
Sourcepub fn cert_algorithm(&mut self, nid: Nid) -> &mut Self
pub fn cert_algorithm(&mut self, nid: Nid) -> &mut Self
The encryption algorithm that should be used for the cert
Sourcepub fn key_iter(&mut self, iter: u32) -> &mut Self
pub fn key_iter(&mut self, iter: u32) -> &mut Self
Key iteration count, default is 2048 as of this writing
Sourcepub fn mac_iter(&mut self, mac_iter: u32) -> &mut Self
pub fn mac_iter(&mut self, mac_iter: u32) -> &mut Self
MAC iteration count, default is the same as key_iter.
Old implementations don’t understand MAC iterations greater than 1, (pre 1.0.1?), if such compatibility is required this should be set to 1.
Sourcepub fn ca(&mut self, ca: Stack<X509>) -> &mut Self
pub fn ca(&mut self, ca: Stack<X509>) -> &mut Self
An additional set of certificates to include in the archive beyond the one provided to
build.
Sourcepub fn build<T>(
self,
password: &str,
friendly_name: &str,
pkey: &PKeyRef<T>,
cert: &X509Ref,
) -> Result<Pkcs12, ErrorStack>where
T: HasPrivate,
pub fn build<T>(
self,
password: &str,
friendly_name: &str,
pkey: &PKeyRef<T>,
cert: &X509Ref,
) -> Result<Pkcs12, ErrorStack>where
T: HasPrivate,
Builds the PKCS #12 object
Arguments
password- the password used to encrypt the key and certificatefriendly_name- user defined name for the certificatepkey- key to storecert- certificate to store